pub struct Terminal { /* private fields */ }Expand description
A terminal instance wrapping a PTY.
Implementations
Sourceimpl Terminal
impl Terminal
Sourcepub fn builder() -> TerminalBuilder
pub fn builder() -> TerminalBuilder
Create a new terminal builder.
Sourcepub async fn type_str(&self, text: &str) -> Result<&Self>
pub async fn type_str(&self, text: &str) -> Result<&Self>
Type a string of text into the terminal.
Sourcepub async fn mouse_move(
&self,
row: u16,
col: u16,
held_buttons: Vec<MouseButton>,
) -> Result<&Self>
pub async fn mouse_move( &self, row: u16, col: u16, held_buttons: Vec<MouseButton>, ) -> Result<&Self>
Move the mouse cursor (hover).
Note: Many TUIs ignore this unless mouse reporting is enabled.
Sourcepub async fn mouse_click(
&self,
row: u16,
col: u16,
button: MouseButton,
) -> Result<&Self>
pub async fn mouse_click( &self, row: u16, col: u16, button: MouseButton, ) -> Result<&Self>
Click a mouse button at the given cell position.
Sourcepub async fn mouse_down(
&self,
row: u16,
col: u16,
button: MouseButton,
) -> Result<&Self>
pub async fn mouse_down( &self, row: u16, col: u16, button: MouseButton, ) -> Result<&Self>
Press a mouse button at the given cell position.
Sourcepub async fn mouse_up(&self, row: u16, col: u16) -> Result<&Self>
pub async fn mouse_up(&self, row: u16, col: u16) -> Result<&Self>
Release any mouse button at the given cell position.
Sourcepub fn expect(&self, text: &str) -> ExpectBuilder<'_>
pub fn expect(&self, text: &str) -> ExpectBuilder<'_>
Wait for specific text to appear on screen.
Sourcepub fn expect_gone(&self, text: &str) -> ExpectBuilder<'_>
pub fn expect_gone(&self, text: &str) -> ExpectBuilder<'_>
Wait for specific text to disappear from screen.
Sourcepub fn expect_pattern(&self, pattern: &str) -> ExpectBuilder<'_>
pub fn expect_pattern(&self, pattern: &str) -> ExpectBuilder<'_>
Wait for a regex pattern to match on screen.
Sourcepub fn expect_pattern_gone(&self, pattern: &str) -> ExpectBuilder<'_>
pub fn expect_pattern_gone(&self, pattern: &str) -> ExpectBuilder<'_>
Wait for a regex pattern to stop matching on screen.
Sourcepub fn wait_cursor(&self, position: Position) -> ExpectBuilder<'_>
pub fn wait_cursor(&self, position: Position) -> ExpectBuilder<'_>
Wait for the cursor to reach a specific position.
Sourcepub fn wait_idle(&self, duration: Duration) -> ExpectBuilder<'_>
pub fn wait_idle(&self, duration: Duration) -> ExpectBuilder<'_>
Wait for the screen to stabilize (no changes for the given duration).
Sourcepub async fn has_exited(&self) -> bool
pub async fn has_exited(&self) -> bool
Check if the process has exited.
Sourcepub fn config(&self) -> &TerminalConfig
pub fn config(&self) -> &TerminalConfig
Get the terminal configuration.
Sourcepub async fn screenshot(&self) -> Screenshot
pub async fn screenshot(&self) -> Screenshot
Take a screenshot of the current screen.
Returns a Screenshot that can be saved to a file or converted to PNG bytes.